name_m = [
    'JOSE',
    'ANTONIO',
    'JUAN',
    'MANUEL',
    'FRANCISCO',
    'LUIS',
    'JAVIER',
    'MIGUEL',
    'CARLOS',
    'ANGEL',
    'JESUS',
    'DAVID',
    'DANIEL',
    'PEDRO',
    'ALEJANDRO',
    'MARIA',
    'ALBERTO',
    'RAFAEL',
    'PABLO',
    'FERNANDO',
    'JORGE',
    'RAMON',
    'SERGIO',
    'ENRIQUE',
    'ANDRES',
    'DIEGO',
    'VICENTE',
    'ADRIAN',
    'VICTOR',
    'ALVARO',
    'IGNACIO',
    'RAUL',
    'EDUARDO',
    'IVAN',
    'OSCAR',
    'RUBEN',
    'JOAQUIN',
    'SANTIAGO',
    'MARIO',
    'ROBERTO',
    'GABRIEL',
    'ALFONSO',
    'JAIME',
    'MARCOS',
    'RICARDO',
    'JULIO',
    'EMILIO',
    'HUGO',
    'SALVADOR',
    'GUILLERMO',
    'MARTIN',
    'MOHAMED',
    'TOMAS',
    'JULIAN',
    'JORDI',
    'NICOLAS',
    'AGUSTIN',
    'GONZALO',
    'CRISTIAN',
    'FELIX',
    'CESAR',
    'MARC',
    'JOSEP',
    'JOAN',
    'SEBASTIAN',
    'SAMUEL',
    'FELIPE',
    'DOMINGO',
    'HECTOR',
    'ISMAEL',
    'ALFREDO',
    'LUCAS',
    'MARIANO',
    'AITOR',
    'ALEX',
    'RODRIGO',
    'IKER',
    'ALEXANDER',
    'XAVIER',
    'ESTEBAN',
    'MATEO',
    'MARCO',
    'GREGORIO',
    'ARTURO',
    'LORENZO',
    'ALBERT',
    'BORJA',
    'EUGENIO',
    'CRISTOBAL',
    'JOEL',
    'AARON',
    'DARIO',
    'ISAAC',
    'JONATHAN',
    'CHRISTIAN',
    'GERMAN',
    'VALENTIN',
    'ADOLFO',
    'ERIC',
    'PAU'
]

name_f = [
    'MARIA',
    'CARMEN',
    'ANA',
    'ISABEL',
    'DOLORES',
    'PILAR',
    'TERESA',
    'ROSA',
    'JOSEFA',
    'CRISTINA',
    'ANGELES',
    'LAURA',
    'ANTONIA',
    'ELENA',
    'MARTA',
    'LUCIA',
    'FRANCISCA',
    'MERCEDES',
    'LUISA',
    'CONCEPCION',
    'ROSARIO',
    'JOSE',
    'PAULA',
    'SARA',
    'RAQUEL',
    'JUANA',
    'ROCIO',
    'EVA',
    'MANUELA',
    'BEATRIZ',
    'PATRICIA',
    'VICTORIA',
    'JESUS',
    'JULIA',
    'ANDREA',
    'BELEN',
    'SILVIA',
    'ALBA',
    'ESTHER',
    'ENCARNACION',
    'NURIA',
    'IRENE',
    'MONTSERRAT',
    'ANGELA',
    'SANDRA',
    'MONICA',
    'INMACULADA',
    'ALICIA',
    'YOLANDA',
    'SONIA',
    'MAR',
    'MARINA',
    'MARGARITA',
    'SUSANA',
    'SOFIA',
    'NATALIA',
    'CLAUDIA',
    'CAROLINA',
    'INES',
    'AMPARO',
    'GLORIA',
    'ALEJANDRA',
    'VERONICA',
    'NIEVES',
    'CARLA',
    'LOURDES',
    'DANIELA',
    'SOLEDAD',
    'LUZ',
    'NOELIA',
    'LORENA',
    'BEGOÑA',
    'FATIMA',
    'OLGA',
    'BLANCA',
    'CONSUELO',
    'ASUNCION',
    'NEREA',
    'MIRIAM',
    'MILAGROS',
    'ESPERANZA',
    'CLARA',
    'LIDIA',
    'CATALINA',
    'CELIA',
    'AURORA',
    'ANNA',
    'ADRIANA',
    'MAGDALENA',
    'MARTINA',
    'EMILIA',
    'ELISA',
    'VANESA',
    'EUGENIA',
    'VIRGINIA',
    'AINHOA',
    'GEMA',
    'JOSEFINA',
    'DIANA',
    'ALEXANDRA'
]

last_names = [
    'García',
    'González',
    'Rodríguez',
    'Fernández',
    'López',
    'Martínez',
    'Sánchez',
    'Pérez',
    'Gómez',
    'Martin',
    'Jiménez',
    'Ruiz',
    'Hernández',
    'Diaz',
    'Moreno',
    'Muñoz',
    'Álvarez',
    'Romero',
    'Alonso',
    'Gutiérrez',
    'Navarro',
    'Torres',
    'Domínguez',
    'Vázquez',
    'Ramos',
    'Gil',
    'Ramírez',
    'Serrano',
    'Blanco',
    'Molina',
    'Morales',
    'Suarez',
    'Ortega',
    'Delgado',
    'Castro',
    'Ortiz',
    'Rubio',
    'Marín',
    'Sanz',
    'Núñez',
    'Iglesias',
    'Medina',
    'Garrido',
    'Cortes',
    'Castillo',
    'Santos',
    'Lozano',
    'Guerrero',
    'Cano',
    'Prieto',
    'Méndez',
    'Cruz',
    'Calvo',
    'Gallego',
    'Vidal',
    'León',
    'Márquez',
    'Herrera',
    'Peña',
    'Flores',
    'Cabrera',
    'Campos',
    'Vega',
    'Fuentes',
    'Carrasco',
    'Diez',
    'Caballero',
    'Reyes',
    'Nieto',
    'Aguilar',
    'Pascual',
    'Santana',
    'Herrero',
    'Lorenzo',
    'Montero',
    'Hidalgo',
    'Giménez',
    'Ibáñez',
    'Ferrer',
    'Duran',
    'Santiago',
    'Benítez',
    'Mora',
    'Vicente',
    'Vargas',
    'Arias',
    'Carmona',
    'Crespo',
    'Román',
    'Pastor',
    'Soto',
    'Sáez',
    'Velasco',
    'Moya',
    'Soler',
    'Parra',
    'Esteban',
    'Bravo',
    'Gallard',
    'Rojas'
]